@@ -66,25 +66,28 @@ dimnames <- list(letters[1:6], LETTERS[1:6])
 for (setDimnames in c(TRUE, FALSE)) {
   if (setDimnames) dimnames(x) <- dimnames
   else dimnames(x) <- NULL
+
+  count <- 0L
   for (rows in index_cases) {
     for (cols in index_cases) {
-      for (na.rm in c(TRUE, FALSE)) {
-        for (useNames in c(NA, TRUE, FALSE)) {
-          validateIndicesTestMatrix(x, rows, cols,
-                                    ftest = rowSds, fsure = rowSds_R,
-                                    na.rm = na.rm, useNames = useNames)
-          validateIndicesTestMatrix(x, rows, cols,
-                                    ftest = rowSds_center, fsure = rowSds_R,
-                                    na.rm = na.rm, center = TRUE, useNames = useNames)
-    
-          validateIndicesTestMatrix(x, rows, cols,
-                                    fcoltest = colSds, fsure = rowSds_R,
-                                    na.rm = na.rm, useNames = useNames)
-          validateIndicesTestMatrix(x, rows, cols,
-                                    fcoltest = colSds_center, fsure = rowSds_R,
-                                    na.rm = na.rm, center = TRUE, useNames = useNames)
-        }
-      }
+      count <- count + 1L
+      na.rm <- c(TRUE, FALSE)[count %% 2 + 1]
+      useNames <- c(if (!matrixStats:::isUseNamesNADefunct()) NA, TRUE, FALSE)
+      useNames <- useNames[count %% length(useNames) + 1]
+      
+      validateIndicesTestMatrix(x, rows, cols,
+                                ftest = rowSds, fsure = rowSds_R,
+                                na.rm = na.rm, useNames = useNames)
+      validateIndicesTestMatrix(x, rows, cols,
+                                ftest = rowSds_center, fsure = rowSds_R,
+                                na.rm = na.rm, center = TRUE, useNames = useNames)
+
+      validateIndicesTestMatrix(x, rows, cols,
+                                fcoltest = colSds, fsure = rowSds_R,
+                                na.rm = na.rm, useNames = useNames)
+      validateIndicesTestMatrix(x, rows, cols,
+                                fcoltest = colSds_center, fsure = rowSds_R,
+                                na.rm = na.rm, center = TRUE, useNames = useNames)
     }
   }
 }
